==> aTunes_1.9.0.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/modules/playlist/PlayListRowOps.java <==
/*
 * aTunes 1.9.0
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.playlist;

import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.handlers.PlayListHandler;
import net.sourceforge.atunes.kernel.handlers.PlayerHandler;
import net.sourceforge.atunes.kernel.handlers.VisualHandler;
import net.sourceforge.atunes.model.AudioObject;

/**
 * The Class PlayListRowOps.
 */
public class PlayListRowOps {

	/**
	 * Move down.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void moveDown(int[] rows) {
		PlayList currentPlayList = PlayerHandler.getInstance().getCurrentPlayList();
		for (int i = rows.length - 1; i >= 0; i--) {
			AudioObject aux = currentPlayList.get(rows[i]);
			currentPlayList.remove(rows[i]);
			currentPlayList.add(rows[i] + 1, aux);
		}
		if (rows[rows.length - 1] + 1 == currentPlayList.getCurrentAudioObjectIndex()) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() - rows.length);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		} else if (rows[0] <= currentPlayList.getCurrentAudioObjectIndex() && currentPlayList.getCurrentAudioObjectIndex() <= rows[rows.length - 1]) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() + 1);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		}
	}

	/**
	 * Move to bottom.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void moveToBottom(int[] rows) {
		PlayList currentPlayList = PlayerHandler.getInstance().getCurrentPlayList();
		int j = 0;
		for (int i = rows.length - 1; i >= 0; i--) {
			AudioObject aux = currentPlayList.get(rows[i]);
			currentPlayList.remove(rows[i]);
			currentPlayList.add(currentPlayList.size() - j++, aux);
		}
		if (rows[rows.length - 1] < currentPlayList.getCurrentAudioObjectIndex()) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() - rows.length);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		} else if (rows[0] <= currentPlayList.getCurrentAudioObjectIndex() && currentPlayList.getCurrentAudioObjectIndex() <= rows[rows.length - 1]) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() + currentPlayList.size() - rows[rows.length - 1] - 1);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		}
	}

	/**
	 * Move to top.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void moveToTop(int[] rows) {
		PlayList currentPlayList = PlayerHandler.getInstance().getCurrentPlayList();
		for (int i = 0; i < rows.length; i++) {
			AudioObject aux = currentPlayList.get(rows[i]);
			currentPlayList.remove(rows[i]);
			currentPlayList.add(i, aux);
		}
		if (rows[0] > currentPlayList.getCurrentAudioObjectIndex()) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() + rows.length);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		} else if (rows[0] <= currentPlayList.getCurrentAudioObjectIndex() && currentPlayList.getCurrentAudioObjectIndex() <= rows[rows.length - 1]) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() - rows[0]);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		}
	}

	/**
	 * Move up.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void moveUp(int[] rows) {
		PlayList currentPlayList = PlayerHandler.getInstance().getCurrentPlayList();
		for (int element : rows) {
			AudioObject aux = currentPlayList.get(element);
			currentPlayList.remove(element);
			currentPlayList.add(element - 1, aux);
		}
		if (rows[0] - 1 == currentPlayList.getCurrentAudioObjectIndex()) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() + rows.length);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		} else if (rows[0] <= currentPlayList.getCurrentAudioObjectIndex() && currentPlayList.getCurrentAudioObjectIndex() <= rows[rows.length - 1]) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() - 1);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		}
	}

	/**
	 * Removes the songs.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void removeSongs(int[] rows) {
		PlayList currentPlayList = PlayerHandler.getInstance().getCurrentPlayList();
		AudioObject playingSong = currentPlayList.getCurrentAudioObject();
		boolean hasToBeRemoved = false;
		for (int element : rows) {
			if (element == currentPlayList.getCurrentAudioObjectIndex())
				hasToBeRemoved = true;
		}
		for (int i = rows.length - 1; i >= 0; i--) {
			currentPlayList.remove(rows[i]);
		}

		if (hasToBeRemoved) {
			PlayerHandler.getInstance().stop(false);
			if (currentPlayList.isEmpty()) {
				PlayListHandler.getInstance().clear();
			} else {
				currentPlayList.setCurrentAudioObject(0);
				ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
				PlayListHandler.getInstance().selectedAudioObjectChanged(currentPlayList.getCurrentAudioObject());
			}
		} else {
			currentPlayList.setCurrentAudioObject(currentPlayList.indexOf(playingSong));
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
			PlayListHandler.getInstance().selectedAudioObjectChanged(currentPlayList.getCurrentAudioObject());
		}

		if (currentPlayList.isEmpty()) {
			ControllerProxy.getInstance().getPlayListControlsController().enableSaveButton(false);
			ControllerProxy.getInstance().getPlayListControlsController().enableShuffleButton(false);
			ControllerProxy.getInstance().getMenuController().enableShufflePlaylist(false);
			ControllerProxy.getInstance().getMenuController().enableSavePlaylist(false);
		}
		VisualHandler.getInstance().showPlayListInformation(currentPlayList);
	}
}

==> aTunes_1.10.1.tar.gz: aTunes/src/net/sourceforge/atunes/kernel/modules/playlist/PlayListRowOps.java <==
/*
 * aTunes 1.10.1
 * Copyright (C) 2006-2008 Alex Aranda, Sylvain Gaudard, Thomas Beckers and contributors
 *
 * See http://www.atunes.org/wiki/index.php?title=Contributing for information about contributors
 *
 * http://www.atunes.org
 * http://sourceforge.net/projects/atunes
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

package net.sourceforge.atunes.kernel.modules.playlist;

import net.sourceforge.atunes.kernel.ControllerProxy;
import net.sourceforge.atunes.kernel.actions.Actions;
import net.sourceforge.atunes.kernel.actions.SavePlayListAction;
import net.sourceforge.atunes.kernel.actions.ShufflePlayListAction;
import net.sourceforge.atunes.kernel.handlers.MultiplePlaylistHandler;
import net.sourceforge.atunes.kernel.handlers.PlayListHandler;
import net.sourceforge.atunes.kernel.handlers.PlayerHandler;
import net.sourceforge.atunes.kernel.handlers.VisualHandler;
import net.sourceforge.atunes.model.AudioObject;

/**
 * The Class PlayListRowOps.
 */
public class PlayListRowOps {

	/**
	 * Move down.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void moveDown(int[] rows) {
		PlayList currentPlayList = MultiplePlaylistHandler.getInstance().getCurrentPlayList();
		for (int i = rows.length - 1; i >= 0; i--) {
			AudioObject aux = currentPlayList.get(rows[i]);
			currentPlayList.remove(rows[i]);
			currentPlayList.add(rows[i] + 1, aux);
		}
		if (rows[rows.length - 1] + 1 == currentPlayList.getCurrentAudioObjectIndex()) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() - rows.length);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		} else if (rows[0] <= currentPlayList.getCurrentAudioObjectIndex() && currentPlayList.getCurrentAudioObjectIndex() <= rows[rows.length - 1]) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() + 1);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		}
	}

	/**
	 * Move to bottom.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void moveToBottom(int[] rows) {
		PlayList currentPlayList = MultiplePlaylistHandler.getInstance().getCurrentPlayList();
		int j = 0;
		for (int i = rows.length - 1; i >= 0; i--) {
			AudioObject aux = currentPlayList.get(rows[i]);
			currentPlayList.remove(rows[i]);
			currentPlayList.add(currentPlayList.size() - j++, aux);
		}
		if (rows[rows.length - 1] < currentPlayList.getCurrentAudioObjectIndex()) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() - rows.length);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		} else if (rows[0] <= currentPlayList.getCurrentAudioObjectIndex() && currentPlayList.getCurrentAudioObjectIndex() <= rows[rows.length - 1]) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() + currentPlayList.size() - rows[rows.length - 1] - 1);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		}
	}

	/**
	 * Move to top.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void moveToTop(int[] rows) {
		PlayList currentPlayList = MultiplePlaylistHandler.getInstance().getCurrentPlayList();
		for (int i = 0; i < rows.length; i++) {
			AudioObject aux = currentPlayList.get(rows[i]);
			currentPlayList.remove(rows[i]);
			currentPlayList.add(i, aux);
		}
		if (rows[0] > currentPlayList.getCurrentAudioObjectIndex()) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() + rows.length);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		} else if (rows[0] <= currentPlayList.getCurrentAudioObjectIndex() && currentPlayList.getCurrentAudioObjectIndex() <= rows[rows.length - 1]) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() - rows[0]);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		}
	}

	/**
	 * Move up.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void moveUp(int[] rows) {
		PlayList currentPlayList = MultiplePlaylistHandler.getInstance().getCurrentPlayList();
		for (int element : rows) {
			AudioObject aux = currentPlayList.get(element);
			currentPlayList.remove(element);
			currentPlayList.add(element - 1, aux);
		}
		if (rows[0] - 1 == currentPlayList.getCurrentAudioObjectIndex()) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() + rows.length);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		} else if (rows[0] <= currentPlayList.getCurrentAudioObjectIndex() && currentPlayList.getCurrentAudioObjectIndex() <= rows[rows.length - 1]) {
			currentPlayList.setCurrentAudioObject(currentPlayList.getCurrentAudioObjectIndex() - 1);
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
		}
	}

	/**
	 * Removes the songs.
	 * 
	 * @param rows
	 *            the rows
	 */
	public static void removeSongs(int[] rows) {
		PlayList currentPlayList = MultiplePlaylistHandler.getInstance().getCurrentPlayList();
		AudioObject playingSong = currentPlayList.getCurrentAudioObject();
		boolean hasToBeRemoved = false;
		for (int element : rows) {
			if (element == currentPlayList.getCurrentAudioObjectIndex()) {
				hasToBeRemoved = true;
			}
		}
		for (int i = rows.length - 1; i >= 0; i--) {
			currentPlayList.remove(rows[i]);
		}

		if (hasToBeRemoved) {
			PlayerHandler.getInstance().stopCurrentAudioObject(false);
			if (currentPlayList.isEmpty()) {
				PlayListHandler.getInstance().clear();
			} else {
				currentPlayList.setCurrentAudioObject(0);
				ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
				PlayListHandler.getInstance().selectedAudioObjectChanged(currentPlayList.getCurrentAudioObject());
			}
		} else {
			currentPlayList.setCurrentAudioObject(currentPlayList.indexOf(playingSong));
			ControllerProxy.getInstance().getPlayListController().setSelectedSong(currentPlayList.getCurrentAudioObjectIndex());
			PlayListHandler.getInstance().selectedAudioObjectChanged(currentPlayList.getCurrentAudioObject());
		}

		if (currentPlayList.isEmpty()) {
			Actions.getAction(SavePlayListAction.class).setEnabled(false);
			Actions.getAction(ShufflePlayListAction.class).setEnabled(false);
		}
		VisualHandler.getInstance().showPlayListInformation(currentPlayList);
	}
}
